illustrate_RPS: Illustration of the Ranked Probability Score
Description
Illustration of the RPS in the case of forecasts for a discrete "Severity" score, ranging from 0 to 10.
The forecast follow a (truncated between 0 and 10) Gaussian distribution, which is discretised to the nearest integer for RPS calculation.
Usage
illustrate_RPS(mu = 5, sigma = 1, observed = 6)
Arguments
mu
Mean of the Gaussian forecast distribution.
sigma
Standard deviation of the Gaussian forecast distribution.
observed
Observed outcome.
Value
Ggplot
Details
The RPS is the mean square error between the cumulative outcome and cumulative forecast distribution (shaded are square).
The Ranked Probability Skill Score compares the RPS to a reference RPS (RPS0), RPSS = 1 - RPS / RPS0.
It can be interpreted as a normalised distance to a reference forecast:
RPSS = 0 means that the forecasts are not better than the reference and RPSS = 1 corresponds to perfect forecasts.