is_wholenumber() uses base::round() to test whether x is a whole number,
it will therefore issue an error if x is not of mode numeric.
If used in base::stopifnot() for example, this won't be a problem but it may be in conditionals.
is_scalar_wholenumber() comes with the additional argument check_numeric
to check whether x is a numeric before checking it is a whole number.